Crate deepspeech_sys

Crate deepspeech_sys 

Structs

CandidateTranscript
@brief A single transcript computed by the model, including a confidence value and the metadata for its constituent tokens.
Metadata
@brief An array of CandidateTranscript objects computed by the model.
ModelState
StreamingState
TokenMetadata
@brief Stores text of an individual token, along with its timing information
max_align_t

Constants

DeepSpeech_Error_Codes_DS_ERR_FAIL_CLEAR_HOTWORD
DeepSpeech_Error_Codes_DS_ERR_FAIL_CREATE_MODEL
DeepSpeech_Error_Codes_DS_ERR_FAIL_CREATE_SESS
DeepSpeech_Error_Codes_DS_ERR_FAIL_CREATE_STREAM
DeepSpeech_Error_Codes_DS_ERR_FAIL_ERASE_HOTWORD
DeepSpeech_Error_Codes_DS_ERR_FAIL_INIT_MMAP
DeepSpeech_Error_Codes_DS_ERR_FAIL_INIT_SESS
DeepSpeech_Error_Codes_DS_ERR_FAIL_INSERT_HOTWORD
DeepSpeech_Error_Codes_DS_ERR_FAIL_INTERPRETER
DeepSpeech_Error_Codes_DS_ERR_FAIL_READ_PROTOBUF
DeepSpeech_Error_Codes_DS_ERR_FAIL_RUN_SESS
DeepSpeech_Error_Codes_DS_ERR_INVALID_ALPHABET
DeepSpeech_Error_Codes_DS_ERR_INVALID_SCORER
DeepSpeech_Error_Codes_DS_ERR_INVALID_SHAPE
DeepSpeech_Error_Codes_DS_ERR_MODEL_INCOMPATIBLE
DeepSpeech_Error_Codes_DS_ERR_NO_MODEL
DeepSpeech_Error_Codes_DS_ERR_OK
DeepSpeech_Error_Codes_DS_ERR_SCORER_INVALID_LM
DeepSpeech_Error_Codes_DS_ERR_SCORER_INVALID_TRIE
DeepSpeech_Error_Codes_DS_ERR_SCORER_NOT_ENABLED
DeepSpeech_Error_Codes_DS_ERR_SCORER_NO_TRIE
DeepSpeech_Error_Codes_DS_ERR_SCORER_UNREADABLE
DeepSpeech_Error_Codes_DS_ERR_SCORER_VERSION_MISMATCH

Functions

DS_AddHotWord⚠
@brief Add a hot-word and its boost.
DS_ClearHotWords⚠
@brief Removes all elements from the hot-words map.
DS_CreateModel⚠
@brief An object providing an interface to a trained DeepSpeech model.
DS_CreateStream⚠
@brief Create a new streaming inference state. The streaming state returned by this function can then be passed to {@link DS_FeedAudioContent()} and {@link DS_FinishStream()}.
DS_DisableExternalScorer⚠
@brief Disable decoding using an external scorer.
DS_EnableExternalScorer⚠
@brief Enable decoding using an external scorer.
DS_EraseHotWord⚠
@brief Remove entry for a hot-word from the hot-words map.
DS_ErrorCodeToErrorMessage⚠
@brief Returns a textual description corresponding to an error code. The string returned must be freed with @{link DS_FreeString()}.
DS_FeedAudioContent⚠
@brief Feed audio samples to an ongoing streaming inference.
DS_FinishStream⚠
@brief Compute the final decoding of an ongoing streaming inference and return the result. Signals the end of an ongoing streaming inference.
DS_FinishStreamWithMetadata⚠
@brief Compute the final decoding of an ongoing streaming inference and return results including metadata. Signals the end of an ongoing streaming inference.
DS_FreeMetadata⚠
@brief Free memory allocated for metadata information.
DS_FreeModel⚠
@brief Frees associated resources and destroys model object.
DS_FreeStream⚠
@brief Destroy a streaming state without decoding the computed logits. This can be used if you no longer need the result of an ongoing streaming inference and don’t want to perform a costly decode operation.
DS_FreeString⚠
@brief Free a char* string returned by the DeepSpeech API.
DS_GetModelBeamWidth⚠
@brief Get beam width value used by the model. If {@link DS_SetModelBeamWidth} was not called before, will return the default value loaded from the model file.
DS_GetModelSampleRate⚠
@brief Return the sample rate expected by a model.
DS_IntermediateDecode⚠
@brief Compute the intermediate decoding of an ongoing streaming inference.
DS_IntermediateDecodeWithMetadata⚠
@brief Compute the intermediate decoding of an ongoing streaming inference, return results including metadata.
DS_SetModelBeamWidth⚠
@brief Set beam width value used by the model.
DS_SetScorerAlphaBeta⚠
@brief Set hyperparameters alpha and beta of the external scorer.
DS_SpeechToText⚠
@brief Use the DeepSpeech model to convert speech to text.
DS_SpeechToTextWithMetadata⚠
@brief Use the DeepSpeech model to convert speech to text and output results including metadata.
DS_Version⚠
@brief Returns the version of this library. The returned version is a semantic version (SemVer 2.0.0). The string returned must be freed with {@link DS_FreeString()}.

Type Aliases

DeepSpeech_Error_Codes
size_t